@@ -5,14 +5,14 @@
 
 import os
 
-from pyutils_spirit.exception import ArgumentException
-
 from typing import Any, Callable, TypeVar
 
 from logging import info, INFO, basicConfig
 
 from pyspark import SparkConf, SparkContext, RDD
 
+from pyutils_spirit.exception.exception import ArgumentException
+
 basicConfig(level=INFO)
 
 T = TypeVar('T')
@@ -28,26 +28,25 @@ class PySparkHandler:
         self.sparkContext = sc
         info(f"Spark version: {sc.version}, Spark created successfully!!!")
 
-    def acceptData(self, data: [list, tuple, dict, set, str]) -> RDD[Any]:
+    def accept_data(self, data: [list, tuple, dict, set, str]) -> RDD[Any]:
         rdd = self.sparkContext.parallelize(data)
         return rdd
 
-    def acceptFile(self, filePath: str) -> RDD[Any]:
-        rdd = self.sparkContext.textFile(filePath)
+    def accept_file(self, file_path: str) -> RDD[Any]:
+        rdd = self.sparkContext.textFile(file_path)
         return rdd
 
-    def operateBySelfAlgorithm(self, data: [list, tuple, dict, set, str],
-                               func: Callable[[T], U], filePath: str = "") -> RDD[Any]:
-        if len(data) == 0 and filePath == "":
+    def operate_by_self_algorithm(self, data: [list, tuple, dict, set, str],
+                                  func: Callable[[T], U], file_path: str = "") -> RDD[Any]:
+        if len(data) == 0 and file_path == "":
             raise ArgumentException("please check operate callable arguments")
         if func is None:
             raise ArgumentException("Type Callable of Func argument must be not None")
         if len(data) == 0:
-            rdd = self.sparkContext.textFile(filePath).map(func)
+            rdd = self.sparkContext.textFile(file_path).map(func)
         else:
             rdd = self.sparkContext.parallelize(data).map(func)
         return rdd
 
     def destroy(self) -> None:
         self.sparkContext.stop()
-
